@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -45,8 +45,9 @@ void export_em_blockmodel_state()
         ([&](auto* s)
          {
              typedef typename std::remove_reference<decltype(*s)>::type state_t;
-             class_<state_t> c(name_demangle(typeid(state_t).name()).c_str(),
-                               no_init);
+             class_<state_t, bases<>, std::shared_ptr<state_t>>
+                 c(name_demangle(typeid(state_t).name()).c_str(),
+                   no_init);
              c.def("learn_iter", &state_t::learn_iter)
                  .def("bp_iter", &state_t::bp_iter)
                  .def("bethe_fe", &state_t::bethe_fe)
