@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -48,7 +48,7 @@ python::object do_gibbs_sweep(python::object ogibbs_state,
            (ogibbs_state,
             [&](auto& s)
             {
-                auto ret_ = gibbs_sweep(s, rng);
+                auto ret_ = gibbs_sweep(*s, rng);
                 ret = tuple_apply([&](auto&... args){ return python::make_tuple(args...); }, ret_);
             });
     };
@@ -71,7 +71,7 @@ public:
 
     virtual std::tuple<double, size_t, size_t> run(rng_t& rng)
     {
-        return gibbs_sweep(_s, rng);
+        return gibbs_sweep(*_s, rng);
     }
 private:
     State _s;
@@ -84,7 +84,7 @@ python::object do_gibbs_sweep_parallel(python::object ogibbs_states,
     std::vector<std::shared_ptr<gibbs_sweep_base>> sweeps;
 
     size_t N = python::len(ogibbs_states);
-    for (size_t i = 0; i < N; ++ i)
+    for (size_t i = 0; i < N; ++i)
     {
         auto dispatch = [&](auto& block_state)
         {
