@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -61,7 +61,7 @@ void export_sbm_state_rmap()
              // void (state_t::*set_partition)(boost::any&) =
              //     &state_t::set_partition;
 
-             class_<state_t, bases<BlockStateVirtualBase>>
+             class_<state_t, bases<BlockStateVirtualBase>, std::shared_ptr<state_t>>
                  c(name_demangle(typeid(state_t).name()).c_str(),
                    no_init);
              c.def("get_B_E",
