@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -21,6 +21,8 @@
 #include "numpy_bind.hh"
 #include "hash_map_wrap.hh"
 
+#include "support/util.hh"
+
 using namespace std;
 using namespace boost;
 using namespace graph_tool;
@@ -144,11 +146,21 @@ extern void export_pp_state();
 extern void export_pp_mcmc();
 extern void export_pp_multiflip_mcmc();
 extern void export_pp_multilevel_mcmc();
+extern void export_ranked_gibbs();
+extern void export_ranked_state();
+extern void export_ranked_mcmc();
+extern void export_ranked_multiflip_mcmc();
+extern void export_ranked_multilevel_mcmc();
 extern void export_modularity_state();
 extern void export_modularity_gibbs();
 extern void export_modularity_mcmc();
 extern void export_modularity_multiflip_mcmc();
 extern void export_modularity_multilevel_mcmc();
+extern void export_norm_cut_state();
+extern void export_norm_cut_gibbs();
+extern void export_norm_cut_mcmc();
+extern void export_norm_cut_multiflip_mcmc();
+extern void export_norm_cut_multilevel_mcmc();
 extern void export_latent_closure_state();
 extern void export_latent_closure_mcmc();
 extern void export_hist_state();
@@ -234,11 +246,21 @@ BOOST_PYTHON_MODULE(libgraph_tool_inference)
     export_pp_mcmc();
     export_pp_multiflip_mcmc();
     export_pp_multilevel_mcmc();
+    export_ranked_state();
+    export_ranked_gibbs();
+    export_ranked_mcmc();
+    export_ranked_multiflip_mcmc();
+    export_ranked_multilevel_mcmc();
     export_modularity_state();
     export_modularity_gibbs();
     export_modularity_mcmc();
     export_modularity_multiflip_mcmc();
     export_modularity_multilevel_mcmc();
+    export_norm_cut_state();
+    export_norm_cut_gibbs();
+    export_norm_cut_mcmc();
+    export_norm_cut_multiflip_mcmc();
+    export_norm_cut_multilevel_mcmc();
     export_latent_closure_state();
     export_latent_closure_mcmc();
     export_hist_state();
@@ -247,8 +269,13 @@ BOOST_PYTHON_MODULE(libgraph_tool_inference)
 
     def("vector_map", vector_map<int32_t>);
     def("vector_map64", vector_map<int64_t>);
+    def("vector_mapdouble", vector_map<double>);
     def("vector_rmap", vector_rmap<int32_t>);
     def("vector_rmap64", vector_rmap<int64_t>);
+    def("vector_rmapdouble", vector_rmap<double>);
     def("vector_contiguous_map", vector_contiguous_map<int32_t>);
     def("vector_contiguous_map64", vector_contiguous_map<int64_t>);
+
+    def("lbinom", lbinom<size_t, size_t>);
+    def("lbinom_fast", lbinom_fast<true, size_t, size_t>);
 }
