@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -68,7 +68,7 @@ void do_exhaustive_layered_sweep(python::object oexhaustive_state,
                      (oexhaustive_state,
                       [&](auto& s)
                       {
-                          exhaustive_sweep(s,
+                          exhaustive_sweep(*s,
                                  [&](auto& state)
                                  {
                                      callback(state._S,
@@ -104,13 +104,12 @@ python::object do_exhaustive_layered_sweep_iter(python::object oexhaustive_state
                          (oexhaustive_state,
                           [&](auto& s)
                           {
-                              exhaustive_sweep
-                                  (s,
-                                   [&](auto& state)
-                                   {
-                                       yield(python::make_tuple(state._S,
-                                                                state._S_min));
-                                   });
+                              exhaustive_sweep(*s,
+                                               [&](auto& state)
+                                               {
+                                                   yield(python::make_tuple(state._S,
+                                                                            state._S_min));
+                                               });
                           });
                  });
             };
@@ -147,7 +146,7 @@ void do_exhaustive_layered_dens(python::object oexhaustive_state,
                      (oexhaustive_state,
                       [&](auto& s)
                       {
-                          exhaustive_sweep(s,
+                          exhaustive_sweep(*s,
                                            [&](auto& state)
                                            {
                                                auto S = state._S;
