@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -62,7 +62,7 @@ python::object gibbs_layered_overlap_sweep(python::object ogibbs_state,
                      (ogibbs_state,
                       [&](auto& s)
                       {
-                          auto ret_ = gibbs_sweep(s, rng);
+                          auto ret_ = gibbs_sweep(*s, rng);
                           ret = tuple_apply([&](auto&... args){ return python::make_tuple(args...); }, ret_);
                       });
              },
@@ -87,7 +87,7 @@ public:
 
     virtual std::tuple<double, size_t, size_t> run(rng_t& rng)
     {
-        return gibbs_sweep(_s, rng);
+        return gibbs_sweep(*_s, rng);
     }
 private:
     State _s;
