@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -63,7 +63,7 @@ python::object vacate_layered_overlap_sweep(python::object ovacate_state,
                      (ovacate_state,
                       [&](auto& s)
                       {
-                          auto ret_ = bundled_vacate_sweep(s, rng);
+                          auto ret_ = bundled_vacate_sweep(*s, rng);
                           ret = tuple_apply([&](auto&... args){ return python::make_tuple(args...); }, ret_);
                       });
              },
