@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -47,7 +47,7 @@ python::object modularity_multiflip_mcmc_sweep(python::object omcmc_state,
            (omcmc_state,
             [&](auto& s)
             {
-                auto ret_ = mcmc_sweep(s, rng);
+                auto ret_ = mcmc_sweep(*s, rng);
                 ret = tuple_apply([&](auto&... args){ return python::make_tuple(args...); }, ret_);
             });
     };
