@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -52,8 +52,10 @@ python::object multicanonical_overlap_multiflip_sweep(python::object omulticanon
 
         mcmc_block_state<state_t>::make_dispatch
             (omulticanonical_state,
-                 [&](auto& mcmc_state)
+                 [&](auto& pmcmc_state)
                  {
+                     auto& mcmc_state = *pmcmc_state;
+
                      typedef typename std::remove_reference<decltype(mcmc_state)>::type
                          mcmc_state_t;
 
@@ -63,7 +65,7 @@ python::object multicanonical_overlap_multiflip_sweep(python::object omulticanon
                          (omulticanonical_state,
                           [&](auto& mc_state)
                           {
-                              auto ret_ = mcmc_sweep(mc_state, rng);
+                              auto ret_ = mcmc_sweep(*mc_state, rng);
                               ret = tuple_apply([&](auto&... args){ return python::make_tuple(args...); }, ret_);
                           });
                  });
