@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -101,7 +101,7 @@ void export_uncertain_state()
                   {
                       typedef typename std::remove_reference<decltype(*s)>::type state_t;
 
-                      class_<state_t>
+                      class_<state_t, bases<>, std::shared_ptr<state_t>>
                           c(name_demangle(typeid(state_t).name()).c_str(),
                             no_init);
                       c.def("remove_edge", &state_t::remove_edge)
