@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -71,8 +71,7 @@ void planar_layout(GraphInterface& gi, boost::any aembed_map, boost::any apos)
                  pos(get(vertex_index_t(), g), num_vertices(g));
 
              chrobak_payne_straight_line_drawing(g, embed, ordering.begin(),
-                                                 ordering.end(), pos,
-                                                 get(vertex_index, g));
+                                                 ordering.end(), pos);
              parallel_vertex_loop
                  (g,
                   [&](auto& v)
