@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -60,6 +60,10 @@ void sfdp_layout(GraphInterface& g, boost::any pos, boost::any vweight,
     typedef vprop_map_t<int32_t>::type c_map_t;
     c_map_t c_map = boost::any_cast<c_map_t>(python::extract<any&>(spring_parms[8])());
 
+    double R = python::extract<double>(spring_parms[9]);
+    typedef vprop_map_t<double>::type o_map_t;
+    o_map_t o_map = boost::any_cast<o_map_t>(python::extract<any&>(spring_parms[10])());
+
     if(vweight.empty())
         vweight = vweight_map_t();
     if(eweight.empty())
@@ -76,6 +80,7 @@ void sfdp_layout(GraphInterface& g, boost::any pos, boost::any vweight,
                                     pin_map.get_unchecked(num_vertices(g.get_graph())),
                                     groups, C, K, p, theta, gamma, mu, kappa, r,
                                     c_map.get_unchecked(num_vertices(g.get_graph())),
+                                    R, o_map.get_unchecked(num_vertices(g.get_graph())),
                                     init_step,
                                     step_schedule, max_level, epsilon, max_iter,
                                     adaptive, verbose, rng);
