@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -114,6 +114,9 @@ void do_bfs(Graph& g, size_t s, Visitor&& vis)
     auto v = vertex(s, g);
     if (v == graph_traits<Graph>::null_vertex())
     {
+        for (auto u : vertices_range(g))
+            vis.initialize_vertex(u, g);
+
         for (auto u : vertices_range(g))
         {
             if (color[u] == color_traits<default_color_type>::black())
@@ -123,7 +126,7 @@ void do_bfs(Graph& g, size_t s, Visitor&& vis)
     }
     else
     {
-        breadth_first_visit(g, v, visitor(vis).color_map(color));
+        breadth_first_search(g, v, visitor(vis).color_map(color));
     }
 }
 
