@@ -1,6 +1,16 @@
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU Lesser General Public License for more details.
+// graph-tool -- a general graph modification and manipulation thingy
+//
+// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
+//
+// This program is free software; you can redistribute it and/or modify it under
+// the terms of the GNU Lesser General Public License as published by the Free
+// Software Foundation; either version 3 of the License, or (at your option) any
+// later version.
+//
+// This program is distributed in the hope that it will be useful, but WITHOUT
+// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+// FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+// details.
 //
 // You should have received a copy of the GNU Lesser General Public License
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
@@ -10,14 +20,12 @@
 
 #include <boost/python.hpp>
 #include <boost/graph/depth_first_search.hpp>
-#include <boost/graph/undirected_dfs.hpp>
 
 #include "graph.hh"
 #include "graph_selectors.hh"
 #include "graph_util.hh"
 
 #include "coroutine.hh"
-#include "graph_python_interface.hh"
 
 using namespace std;
 using namespace boost;
