@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -38,13 +38,11 @@ struct do_all_pairs_search
         typedef typename property_traits<DistMap>::value_type::value_type
             dist_t;
 
-        parallel_vertex_loop
-            (g,
-             [&](auto& v)
-             {
-                 dist_map[v].clear();
-                 dist_map[v].resize(num_vertices(g), 0);
-             });
+        for (size_t v = 0; v < num_vertices(g); ++v)
+        {
+            dist_map[v].clear();
+            dist_map[v].resize(num_vertices(g), 0);
+        }
 
         if (dense)
         {
