@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -228,19 +228,18 @@ subgraph_isomorphism(GraphInterface& gi1, GraphInterface& gi2,
     if (!generator)
     {
         gt_dispatch<>()
-            (
-                [&](auto&& graph, auto&& a2, auto&& a3, auto&& a4)
-                {
-                    return get_subgraphs()
-                        (std::forward<decltype(graph)>(graph),
-                         std::forward<decltype(a2)>(a2),
-                         std::forward<decltype(a3)>(a3), vertex_label2,
-                         std::forward<decltype(a4)>(a4), edge_label2, vmaps,
-                         max_n, induced, iso, ListMatch());
-                },
-                all_graph_views(), all_graph_views(), vertex_props_t(),
-                edge_props_t())(gi1.get_graph_view(), gi2.get_graph_view(),
-                                vertex_label1, edge_label1);
+            ([&](auto&& graph, auto&& a2, auto&& a3, auto&& a4)
+             {
+                 return get_subgraphs()
+                     (std::forward<decltype(graph)>(graph),
+                      std::forward<decltype(a2)>(a2),
+                      std::forward<decltype(a3)>(a3), vertex_label2,
+                      std::forward<decltype(a4)>(a4), edge_label2, vmaps,
+                      max_n, induced, iso, ListMatch());
+             },
+             all_graph_views(), all_graph_views(), vertex_props_t(),
+             edge_props_t())(gi1.get_graph_view(), gi2.get_graph_view(),
+                             vertex_label1, edge_label1);
 
         python::list vmapping;
         for (auto& vmap: vmaps)
@@ -263,8 +262,8 @@ subgraph_isomorphism(GraphInterface& gi1, GraphInterface& gi2,
                           std::forward<decltype(a4)>(a4), edge_label2, vmaps,
                           max_n, induced, iso, GenMatch(yield));
                  },
-                 all_graph_views(), vertex_props_t(), edge_props_t())(
-                    gi2.get_graph_view(), vertex_label1, edge_label1);
+                 all_graph_views(), vertex_props_t(), edge_props_t())
+                (gi2.get_graph_view(), vertex_label1, edge_label1);
         };
         CoroGenerator gen(dispatch);
         return boost::python::object(gen);
