@@ -3,7 +3,7 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -72,7 +72,7 @@ from .. import Graph, GraphView, _check_prop_vector, _check_prop_scalar, \
 from .. topology import max_cardinality_matching, max_independent_vertex_set, \
     label_components, shortest_distance, make_maximal_planar, is_planar
 from .. generation import predecessor_tree, condensation_graph
-from .. inference import nested_contiguous_map
+from .. inference.util import nested_contiguous_map
 import numpy.random
 from numpy import sqrt
 
@@ -212,7 +212,6 @@ def planar_layout(g, pos=None):
         pos = u.new_vp("vector<double>")
     else:
         pos = u.own_property(pos)
-    make_maximal_planar(u)
     libgraph_tool_layout.planar_layout(u._Graph__graph,
                                        _prop("v", u, embed),
                                        _prop("v", u, pos))
@@ -524,7 +523,7 @@ def coarse_graphs(g, method="hybrid", mivs_thres=0.9, ec_thres=0.75,
 
 def sfdp_layout(g, vweight=None, eweight=None, pin=None, groups=None, C=0.2,
                 K=None, p=2., theta=0.6, max_level=15, r=1., gamma=.3, mu=2.,
-                kappa=1., init_step=None, cooling_step=0.95,
+                kappa=1., rmap=None, R=1, init_step=None, cooling_step=0.95,
                 adaptive_cooling=True, epsilon=1e-2, max_iter=0, pos=None,
                 multilevel=None, coarse_method="hybrid", mivs_thres=0.9,
                 ec_thres=0.75, weighted_coarse=False, verbose=False):
@@ -559,10 +558,15 @@ def sfdp_layout(g, vweight=None, eweight=None, pin=None, groups=None, C=0.2,
         Strength of attractive force between connected components.
     gamma : float (optional, default: ``.3``)
         Strength of the repulsive force between different groups.
-    mu : float (optional, default: ``3.0``)
-        Exponent of the strength of the repulsive force between different groups.
+    mu : float (optional, default: ``2``)
+        Typical length of the repulsive force between different groups.
     kappa : float (optional, default: ``1.0``)
         Multiplicative factor on the attracttive force between nodes of the same group.
+    rmap : :class:`~graph_tool.VertexPropertyMap` (optional, default: ``None``)
+        Vertex rank to be used around to order them preferentially in the
+        :math:`y` direction.
+    R : float (optional, default: ``1.0``)
+        Strength of the rank ordering in the :math:`y` direction.
     init_step : float (optional, default: ``None``)
         Initial update step. If not provided, it will be chosen automatically.
     cooling_step : float (optional, default: ``0.95``)
@@ -632,6 +636,7 @@ def sfdp_layout(g, vweight=None, eweight=None, pin=None, groups=None, C=0.2,
     .. [hu-multilevel-2005] Yifan Hu, "Efficient and High Quality Force-Directed
        Graph", Mathematica Journal, vol. 10, Issue 1, pp. 37-71, (2005)
        http://www.mathematica-journal.com/issue/v10i1/graph_draw.html
+
     """
 
     if pos is None:
@@ -655,6 +660,14 @@ def sfdp_layout(g, vweight=None, eweight=None, pin=None, groups=None, C=0.2,
     if K is None:
         K = _avg_edge_distance(g, pos)
 
+    mu *= K
+
+    if rmap is None:
+        rmap = g.new_vp("double")
+        R = 0
+    elif rmap.value_type() != "double":
+        rmap = rmap.copy("double")
+
     if init_step is None:
         init_step = 2 * max(_avg_edge_distance(g, pos), K)
 
@@ -682,7 +695,7 @@ def sfdp_layout(g, vweight=None, eweight=None, pin=None, groups=None, C=0.2,
                               eweight=ecount if weighted_coarse else None,
                               groups=groups,
                               C=C, K=K, p=p,
-                              theta=theta, gamma=gamma, mu=mu,
+                              theta=theta, gamma=gamma, mu=mu, kappa=kappa,
                               epsilon=epsilon,
                               max_iter=max_iter,
                               cooling_step=cooling_step,
@@ -715,7 +728,7 @@ def sfdp_layout(g, vweight=None, eweight=None, pin=None, groups=None, C=0.2,
                                      _prop("e", g, eweight),
                                      _prop("v", g, pin),
                                      (C, K, p, gamma, mu, kappa, groups, r,
-                                      _prop("v", g, c)),
+                                      _prop("v", g, c), R, _prop("v", g, rmap)),
                                      theta, init_step, cooling_step, max_level,
                                      epsilon, max_iter, not adaptive_cooling,
                                      verbose, _get_rng())
