@@ -3,7 +3,7 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -18,7 +18,7 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from .. import Vector_size_t
+from .. import Vector_size_t, group_vector_property
 
 from . util import *
 
@@ -28,6 +28,8 @@ import gc
 
 import numpy
 
+import graph_tool.draw
+
 __test__ = False
 
 def set_test(test):
@@ -40,16 +42,16 @@ def _bm_test():
 
 def copy_state_wrap(func):
     @functools.wraps(func)
-    def wrapper(self, *args, **kwargs):
+    def wrapper(self, *args, test=True, **kwargs):
 
         S = func(self, *args, **kwargs)
 
-        if kwargs.pop("test", True) and _bm_test():
+        if _bm_test() and test:
             assert not isnan(S) and not isinf(S), \
                 "invalid entropy %g (%s) " % (S, str(args))
 
             state_copy = self.copy()
-            Salt = state_copy.entropy(*args, **dict(kwargs, test=False))
+            Salt = state_copy.entropy(*args, test=False, **kwargs)
 
             assert math.isclose(S, Salt, abs_tol=1e-8), \
                 "entropy discrepancy after copying (%g %g %g)" % (S, Salt,
@@ -121,7 +123,7 @@ class MCMCState(ABC):
             made for each node.
         entropy_args : ``dict`` (optional, default: ``{}``)
             Entropy arguments, with the same meaning and defaults as in
-            :meth:`graph_tool.inference.blockmodel.BlockState.entropy`.
+            :meth:`graph_tool.inference.BlockState.entropy`.
         allow_vacate : ``bool`` (optional, default: ``True``)
             Allow groups to be vacated.
         sequential : ``bool`` (optional, default: ``True``)
@@ -197,9 +199,9 @@ class MultiflipMCMCState(ABC):
 
     @mcmc_sweep_wrap
     def multiflip_mcmc_sweep(self, beta=1., c=.5, psingle=None, psplit=1,
-                             pmerge=1, pmergesplit=1, d=0.01, gibbs_sweeps=10,
-                             niter=1, entropy_args={}, accept_stats=None,
-                             verbose=False, **kwargs):
+                             pmerge=1, pmergesplit=1, pmovelabel=0, d=0.01,
+                             gibbs_sweeps=10, niter=1, entropy_args={},
+                             accept_stats=None, verbose=False, **kwargs):
         r"""Perform ``niter`` sweeps of a Metropolis-Hastings acceptance-rejection MCMC
         with multiple simultaneous moves (i.e. merges and splits) to sample
         network partitions.
@@ -221,6 +223,8 @@ class MultiflipMCMCState(ABC):
             Relative probability of proposing a group split.
         pmergesplit : ``float`` (optional, default: ``1``)
             Relative probability of proposing a marge-split move.
+        pmovelabel : ``float`` (optional, default: ``0``)
+            Relative probability of proposing a group label move.
         d : ``float`` (optional, default: ``1``)
             Probability of selecting a new (i.e. empty) group for a given
             single-node move.
@@ -232,7 +236,7 @@ class MultiflipMCMCState(ABC):
             made for each node, on average.
         entropy_args : ``dict`` (optional, default: ``{}``)
             Entropy arguments, with the same meaning and defaults as in
-            :meth:`graph_tool.inference.blockmodel.BlockState.entropy`.
+            :meth:`graph_tool.inference.BlockState.entropy`.
         verbose : ``bool`` (optional, default: ``False``)
             If ``verbose == True``, detailed information will be displayed.
 
@@ -332,7 +336,7 @@ class MultilevelMCMCState(ABC):
             it will be selected as the number of nodes in the graph.
         pmultilevel : ``float`` (optional, default: ``1``)
             Relative probability of proposing a multilevel move.
-        d : ``float`` (optional, default: ``1``)
+        d : ``float`` (optional, default: ``.01``)
             Probability of selecting a new (i.e. empty) group for a given
             single-node move.
         r : ``float`` (optional, default: ``0.9``)
@@ -373,7 +377,7 @@ class MultilevelMCMCState(ABC):
             search.
         entropy_args : ``dict`` (optional, default: ``{}``)
             Entropy arguments, with the same meaning and defaults as in
-            :meth:`graph_tool.inference.blockmodel.BlockState.entropy`.
+            :meth:`graph_tool.inference.BlockState.entropy`.
         verbose : ``bool`` (optional, default: ``False``)
             If ``verbose == True``, detailed information will be displayed.
 
@@ -458,7 +462,7 @@ class GibbsMCMCState(ABC):
             made for each node.
         entropy_args : ``dict`` (optional, default: ``{}``)
             Entropy arguments, with the same meaning and defaults as in
-            :meth:`graph_tool.inference.blockmodel.BlockState.entropy`.
+            :meth:`graph_tool.inference.BlockState.entropy`.
         allow_new_group : ``bool`` (optional, default: ``True``)
             Allow the number of groups to increase and decrease.
         sequential : ``bool`` (optional, default: ``True``)
@@ -523,8 +527,8 @@ class MulticanonicalMCMCState(ABC):
 
         Parameters
         ----------
-        m_state : :class:`~graph_tool.inference.mcmc.MulticanonicalState`
-            :class:`~graph_tool.inference.mcmc.MulticanonicalState` instance
+        m_state : :class:`~graph_tool.inference.MulticanonicalState`
+            :class:`~graph_tool.inference.MulticanonicalState` instance
             containing the current state of the Wang-Landau run.
         multiflip : ``bool`` (optional, default: ``False``)
             If ``True``, ``multiflip_mcmc_sweep()`` will be used, otherwise
@@ -611,7 +615,7 @@ class ExhaustiveSweepState(ABC):
         ----------
         entropy_args : ``dict`` (optional, default: ``{}``)
             Entropy arguments, with the same meaning and defaults as in
-            :meth:`graph_tool.inference.blockmodel.BlockState.entropy`.
+            :meth:`graph_tool.inference.BlockState.entropy`.
         callback : callable object (optional, default: ``None``)
             Function to be called for each partition, with three arguments ``(S,
             S_min, b_min)`` corresponding to the the current entropy value, the
@@ -690,3 +694,21 @@ class ExhaustiveSweepState(ABC):
                 return (Ss, density[2]), b_min
         else:
             return b_min
+
+
+class DrawBlockState(ABC):
+    r"""Base state that implements group-based drawing."""
+
+    def draw(self, **kwargs):
+        r"""Convenience wrapper to :func:`~graph_tool.draw.graph_draw` that
+        draws the state of the graph as colors on the vertices and edges."""
+        gradient = self.g.new_ep("double")
+        gradient = group_vector_property([gradient])
+        b = self.g.own_property(self.b)
+        return graph_tool.draw.graph_draw(self.g,
+                                          vertex_fill_color=kwargs.get("vertex_fill_color", b),
+                                          vertex_color=kwargs.get("vertex_color", b),
+                                          edge_gradient=kwargs.get("edge_gradient", gradient),
+                                          **dmask(kwargs, ["vertex_fill_color",
+                                                           "vertex_color",
+                                                           "edge_gradient"]))
