@@ -3,7 +3,7 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -20,8 +20,8 @@
 
 from .. import _prop, Graph, GraphView, _get_rng, PropertyMap, \
     edge_endpoint_property, Vector_size_t
-from .. generation import generate_triadic_closure
-from .. stats import remove_parallel_edges,  remove_self_loops
+from .. generation import generate_triadic_closure, remove_parallel_edges, \
+    remove_self_loops
 from .. spectral import adjacency
 
 from .. dl_import import dl_import
@@ -199,8 +199,8 @@ class LatentLayerBaseState(object):
         sample network partitions and latent edges. The parameter ``r`` controls
         the probability with which edge move will be attempted, instead of
         partition moves. The remaining keyword parameters will be passed to
-        :meth:`~graph_tool.inference.blockmodel.BlockState.mcmc_sweep` or
-        :meth:`~graph_tool.inference.blockmodel.BlockState.multiflip_mcmc_sweep`,
+        :meth:`~graph_tool.inference.BlockState.mcmc_sweep` or
+        :meth:`~graph_tool.inference.BlockState.multiflip_mcmc_sweep`,
         if ``multiflip=True``.
         """
 
@@ -232,13 +232,13 @@ class LatentClosureBlockState(LatentLayerBaseState):
         Expected total number of edges used in prior. If ``NaN``, a flat
         prior will be used instead.
     nested : ``boolean`` (optional, default: ``True``)
-        If ``True``, a :class:`~graph_tool.inference.nested_blockmodel.NestedBlockState`
+        If ``True``, a :class:`~graph_tool.inference.NestedBlockState`
         will be used, otherwise
-        :class:`~graph_tool.inference.blockmodel.BlockState`.
+        :class:`~graph_tool.inference.BlockState`.
     state_args : ``dict`` (optional, default: ``{}``)
         Arguments to be passed to
-        :class:`~graph_tool.inference.nested_blockmodel.NestedBlockState` or
-        :class:`~graph_tool.inference.blockmodel.BlockState`.
+        :class:`~graph_tool.inference.NestedBlockState` or
+        :class:`~graph_tool.inference.BlockState`.
     g_orig : :class:`~graph_tool.Graph` (optional, default: ``None``)
         Original graph, if ``g`` is used to initialize differently from a graph with no triadic closure edges.
     ew : list of :class:`~graph_tool.EdgePropertyMap` (optional, default: ``None``)
@@ -582,14 +582,14 @@ class MeasuredClosureBlockState(LatentClosureBlockState, UncertainBaseState):
         Expected total number of edges used in prior. If ``NaN``, a flat
         prior will be used instead.
     nested : ``boolean`` (optional, default: ``True``)
-        If ``True``, a :class:`~graph_tool.inference.nested_blockmodel.NestedBlockState`
+        If ``True``, a :class:`~graph_tool.inference.NestedBlockState`
         will be used, otherwise
-        :class:`~graph_tool.inference.blockmodel.BlockState`.
+        :class:`~graph_tool.inference.BlockState`.
     state_args : ``dict`` (optional, default: ``{}``)
         Arguments to be passed to
-        :class:`~graph_tool.inference.nested_blockmodel.NestedBlockState` or
-        :class:`~graph_tool.inference.blockmodel.BlockState`.
-    bstate : :class:`~graph_tool.inference.nested_blockmodel.NestedBlockState` or :class:`~graph_tool.inference.blockmodel.BlockState`  (optional, default: ``None``)
+        :class:`~graph_tool.inference.NestedBlockState` or
+        :class:`~graph_tool.inference.BlockState`.
+    bstate : :class:`~graph_tool.inference.NestedBlockState` or :class:`~graph_tool.inference.BlockState`  (optional, default: ``None``)
         If passed, this will be used to initialize the block state
         directly.
     g_orig : :class:`~graph_tool.Graph` (optional, default: ``None``)
