@@ -3,7 +3,7 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -41,11 +41,11 @@ class NestedBlockState(object):
     bs : ``list`` of :class:`~graph_tool.VertexPropertyMap` or :class:`numpy.ndarray` (optional, default: ``None``)
         Hierarchical node partition. If not provided it will correspond to a
         single-group hierarchy of length :math:`\lceil\log_2(N)\rceil`.
-    base_type : ``type`` (optional, default: :class:`~graph_tool.inference.blockmodel.BlockState`)
+    base_type : ``type`` (optional, default: :class:`~graph_tool.inference.BlockState`)
         State type for lowermost level
-        (e.g. :class:`~graph_tool.inference.blockmodel.BlockState`,
-        :class:`~graph_tool.inference.overlap_blockmodel.OverlapBlockState` or
-        :class:`~graph_tool.inference.layered_blockmodel.LayeredBlockState`)
+        (e.g. :class:`~graph_tool.inference.BlockState`,
+        :class:`~graph_tool.inference.OverlapBlockState` or
+        :class:`~graph_tool.inference.LayeredBlockState`)
     hstate_args : ``dict`` (optional, default: `{}`)
         Keyword arguments to be passed to the constructor of the higher-level
         states.
@@ -93,16 +93,17 @@ class NestedBlockState(object):
                                   recs_dl=False,
                                   beta_dl=1.)
 
+        self.levels = [base_type(g, b=bs[0] if bs is not None else None,
+                                 **self.state_args)]
+
         if bs is None:
             if base_type is OverlapBlockState:
-                N = 2 * g.num_edges()
+                N = 2 * self.levels[0].get_N()
             else:
-                N = g.num_vertices()
+                N = self.levels[0].get_N()
             L = int(numpy.ceil(numpy.log2(N)))
             bs = [None] * (L + 1)
 
-        self.levels = [base_type(g, b=bs[0], **self.state_args)]
-
         for i, b in enumerate(bs[1:]):
             state = self.levels[-1]
             args = self.hstate_args
@@ -119,6 +120,9 @@ class NestedBlockState(object):
             self._consistency_check()
 
     def _regen_Lrecdx(self, lstate=None):
+        if not hasattr(self.levels[0], "recdx"):
+            return
+
         if lstate is None:
             levels = self.levels
             Lrecdx = self.Lrecdx
@@ -183,27 +187,25 @@ class NestedBlockState(object):
     def __copy__(self):
         return self.copy()
 
-    def __deepcopy__(self, memo):
-        g = copy.deepcopy(self.g, memo)
-        return self.copy(g=g)
-
-    def copy(self, g=None, bs=None, state_args=None, hstate_args=None,
-             hentropy_args=None, **kwargs):
+    def copy(self, **kwargs):
         r"""Copies the block state. The parameters override the state properties,
         and have the same meaning as in the constructor."""
-        bs = self.get_bs() if bs is None else bs
-        return NestedBlockState(self.g if g is None else g, bs,
-                                base_type=type(self.levels[0]),
-                                state_args=self.state_args if state_args is None else state_args,
-                                hstate_args=self.hstate_args if hstate_args is None else hstate_args,
-                                hentropy_args=self.hentropy_args if hentropy_args is None else hentropy_args,
-                                **kwargs)
+        state = dict(self.__getstate__(), **kwargs)
+        return NestedBlockState(**state)
 
     def __getstate__(self):
-        state = dict(g=self.g, bs=self.get_bs(), base_type=type(self.levels[0]),
+        base_state = self.levels[0].__getstate__()
+        base_state.pop("Lrecdx", None)
+        base_state.pop("epsilon", None)
+        base_state.pop("drec", None)
+        state_args = dict(self.state_args, **base_state)
+        state_args.pop("g", None)
+        state_args.pop("b", None)
+        state = dict(g=self.g, bs=self.get_bs(),
+                     base_type=type(self.levels[0]),
                      hstate_args=self.hstate_args,
                      hentropy_args=self.hentropy_args,
-                     state_args=self.state_args)
+                     state_args=state_args)
         return state
 
     def __setstate__(self, state):
@@ -225,7 +227,7 @@ class NestedBlockState(object):
             self.levels[i].set_state(bs[i])
 
     def get_levels(self):
-        """Get hierarchy levels as a list of :class:`~graph_tool.inference.blockmodel.BlockState`
+        """Get hierarchy levels as a list of :class:`~graph_tool.inference.BlockState`
         instances."""
         return self.levels
 
@@ -306,6 +308,9 @@ class NestedBlockState(object):
         return S
 
     def _Lrecdx_entropy(self, Lrecdx=None):
+        if not hasattr(self.levels[0], "recdx"):
+            return 0
+
         if self.base_type is not LayeredBlockState:
             S_D = 0
 
@@ -355,9 +360,9 @@ class NestedBlockState(object):
 
         The keyword arguments are passed to the ``entropy()`` method of the
         underlying state objects
-        (e.g. :class:`graph_tool.inference.blockmodel.BlockState.entropy`,
-        :class:`graph_tool.inference.overlap_blockmodel.OverlapBlockState.entropy`, or
-        :class:`graph_tool.inference.layered_blockmodel.LayeredBlockState.entropy`).  """
+        (e.g. :class:`graph_tool.inference.BlockState.entropy`,
+        :class:`graph_tool.inference.OverlapBlockState.entropy`, or
+        :class:`graph_tool.inference.LayeredBlockState.entropy`).  """
         S = 0
         for l in range(len(self.levels)):
             S += self.level_entropy(l, **dict(kwargs, test=False))
@@ -414,7 +419,7 @@ class NestedBlockState(object):
         (with missing edges added and spurious edges deleted).
 
         The values in ``entropy_args`` are passed to
-        :meth:`graph_tool.inference.blockmodel.BlockState.entropy()` to calculate the
+        :meth:`graph_tool.inference.BlockState.entropy()` to calculate the
         log-probability.
         """
 
@@ -538,8 +543,11 @@ class NestedBlockState(object):
             else:
                 args = dict(kwargs, entropy_args=eargs, c=c[l])
 
-            if l > 0 and "beta_dl" in entropy_args:
-                args = dict(args, beta=args.get("beta", 1.) * entropy_args["beta_dl"])
+            if l > 0:
+                if "beta_dl" in entropy_args:
+                    args = dict(args, beta=args.get("beta", 1.) * entropy_args["beta_dl"])
+                for p in ["B_max", "B_min", "b_max", "b_min", "vertices"]:
+                    args.pop(p, None)
 
             yield l, self.levels[l], args
 
@@ -591,7 +599,7 @@ class NestedBlockState(object):
         MCMC to sample hierarchical network partitions.
 
         The arguments accepted are the same as in
-        :meth:`graph_tool.inference.blockmodel.BlockState.mcmc_sweep`.
+        :meth:`graph_tool.inference.BlockState.mcmc_sweep`.
 
         If the parameter ``c`` is a scalar, the values used at each level are
         ``c * 2 ** l`` for ``l`` in the range ``[0, L-1]``. Optionally, a list
@@ -628,7 +636,7 @@ class NestedBlockState(object):
         with multiple moves to sample hierarchical network partitions.
 
         The arguments accepted are the same as in
-        :meth:`graph_tool.inference.blockmodel.BlockState.multiflip_mcmc_sweep`.
+        :meth:`graph_tool.inference.BlockState.multiflip_mcmc_sweep`.
 
         If the parameter ``c`` is a scalar, the values used at each level are
         ``c * 2 ** l`` for ``l`` in the range ``[0, L-1]``. Optionally, a list
@@ -644,7 +652,7 @@ class NestedBlockState(object):
 
         """
 
-        kwargs["psingle"] = kwargs.get("psingle", self.g.num_vertices())
+        kwargs["psingle"] = kwargs.get("psingle", self.levels[0].get_N())
 
         c = kwargs.pop("c", 1)
         if not isinstance(c, collections.abc.Iterable):
@@ -675,7 +683,7 @@ class NestedBlockState(object):
         with multilevel moves to sample hierarchical network partitions.
 
         The arguments accepted are the same as in
-        :meth:`graph_tool.inference.blockmodel.BlockState.multilevel_mcmc_sweep`.
+        :meth:`graph_tool.inference.BlockState.multilevel_mcmc_sweep`.
 
         If the parameter ``c`` is a scalar, the values used at each level are
         ``c * 2 ** l`` for ``l`` in the range ``[0, L-1]``. Optionally, a list
@@ -714,7 +722,7 @@ class NestedBlockState(object):
         to sample network partitions.
 
         The arguments accepted are the same as in
-        :meth:`graph_tool.inference.blockmodel.BlockState.gibbs_sweep`.
+        :meth:`graph_tool.inference.BlockState.gibbs_sweep`.
 
         .. warning::
 
@@ -737,7 +745,7 @@ class NestedBlockState(object):
         Wang-Landau algorithm.
 
         The arguments accepted are the same as in
-        :meth:`graph_tool.inference.blockmodel.BlockState.multicanonical_sweep`.
+        :meth:`graph_tool.inference.BlockState.multicanonical_sweep`.
         """
 
         def sweep(s, **kwargs):
@@ -754,11 +762,11 @@ class NestedBlockState(object):
         r"""Collect a histogram of partitions.
 
         This should be called multiple times, e.g. after repeated runs of the
-        :meth:`graph_tool.inference.nested_blockmodel.NestedBlockState.mcmc_sweep` function.
+        :meth:`graph_tool.inference.NestedBlockState.mcmc_sweep` function.
 
         Parameters
         ----------
-        h : :class:`~graph_tool.inference.blockmodel.PartitionHist` (optional, default: ``None``)
+        h : :class:`~graph_tool.inference.PartitionHist` (optional, default: ``None``)
             Partition histogram. If not provided, an empty histogram will be created.
         update : float (optional, default: ``1``)
             Each call increases the current count by the amount given by this
@@ -766,7 +774,7 @@ class NestedBlockState(object):
 
         Returns
         -------
-        h : :class:`~graph_tool.inference.blockmodel.PartitionHist` (optional, default: ``None``)
+        h : :class:`~graph_tool.inference.PartitionHist` (optional, default: ``None``)
             Updated Partition histogram.
 
         """
@@ -786,13 +794,13 @@ class NestedBlockState(object):
 def get_hierarchy_tree(state, empty_branches=False):
     r"""Obtain the nested hierarchical levels as a tree.
 
-    This transforms a :class:`~graph_tool.inference.nested_blockmodel.NestedBlockState` instance
+    This transforms a :class:`~graph_tool.inference.NestedBlockState` instance
     into a single :class:`~graph_tool.Graph` instance containing the hierarchy
     tree.
 
     Parameters
     ----------
-    state : :class:`~graph_tool.inference.nested_blockmodel.NestedBlockState`
+    state : :class:`~graph_tool.inference.NestedBlockState`
        Nested block model state.
     empty_branches : ``bool`` (optional, default: ``False``)
        If ``empty_branches == False``, dangling branches at the upper layers
@@ -886,20 +894,14 @@ def get_hierarchy_tree(state, empty_branches=False):
         vmask = t.new_vertex_property("bool", True)
         t = GraphView(t, vfilt=vmask)
         vmask = t.get_vertex_filter()[0]
-
-        for vi in range(state.g.num_vertices(ignore_filter=True),
-                        t.num_vertices()):
-            v = t.vertex(t_vertices[vi])
+        N = t.num_vertices()
+        for vi, v in enumerate(list(t.vertices())):
+            if vi < state.g.num_vertices():
+                continue
             if v.out_degree() == 0:
                 vmask[v] = False
-
-        t.vp.label = label
-        t.vp.order = order
-        t = Graph(t, prune=True)
-        label = t.vp.label
-        order = t.vp.order
-        del t.vp["label"]
-        del t.vp["order"]
+        label = t.own_property(label)
+        order = t.own_property(order)
 
     return t, label, order
 
